@@ -38,18 +38,20 @@ function setupDebounces(ws) {
         element.dataset[`auto${action}DebouncePeriod`],
         10
       );
-      visibleInput.addEventListener(
-        "input",
-        debounce(() => {
-          const currentInput = document.getElementById(
-            element.dataset.relatedFormId
-          );
-          const currentValue = currentInput.value;
-          ws.send(
-            JSON.stringify({ action, dataset: element.dataset, currentValue })
-          );
-        }, debouncePeriodMs)
-      );
+      const debounced = debounce(() => {
+        const currentInput = document.getElementById(
+          element.dataset.relatedFormId
+        );
+        const currentValue = currentInput.value;
+        ws.send(
+          JSON.stringify({ action, dataset: element.dataset, currentValue })
+        );
+      }, debouncePeriodMs);
+      visibleInput.addEventListener("input", () => {
+        visibleInput.dataset.nangoState = "unknown";
+        console.log("unknown");
+        debounced();
+      });
     });
   });
 }
@@ -123,10 +125,12 @@ function nangoOnClean(data) {
     // update the form input to show the cleaned value as returned from django
     visibleInput.value = data.cleanedValue;
     visibleInput.dataset.nangoState = "clean";
+    console.log("clean");
     return;
   }
   if (data.validationErrors) {
     visibleInput.dataset.nangoState = "dirty";
+    console.log("dirty");
     nangoShowValidationError(data.dataset.relatedFormId, data.validationErrors);
   }
 }
